@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-VERSION = '0.3.1'
+VERSION = '0.3.2'
 
 import os
 import sys
@@ -16,9 +16,17 @@ import argparse
 import string
 import curses
 
-screen = curses.initscr()
-(_, width) = screen.getmaxyx()
-curses.endwin()
+width = 20
+def set_screen_width():
+    return
+    global width
+    try:
+        screen = curses.initscr()
+        (_, width) = screen.getmaxyx()
+        curses.endwin()
+    except:
+        width = 20
+
 
 def get_args():
     parser = argparse.ArgumentParser(
@@ -342,7 +350,7 @@ kernel /boot/vmlinuz-{0}_{1} root={2} ro\n'''.format(
         if not os.path.isfile('/boot/grub/menu.lst'):
             self.log('Creating initial menu.lst')
             with open('/boot/grub/menu.lst', 'w') as handle:
-                handle.write('timeout 25\ndefault0\n\n#START\n')
+                handle.write('timeout 25\ndefault 0\n\n#START\n')
         self.log('Inserting new kernel into menu.lst')
         done = False
         for line in fileinput.input('/boot/grub/menu.lst', inplace=True):
@@ -365,6 +373,9 @@ def easy_roll():
     args = get_args()
     kernel = Kernel(verbose=args.verbose)
 
+    if args.verbose:
+        set_screen_width()
+
     kernel.version = args.new_version
     kernel.config_version = args.config_version
     kernel.config_revision = args.config_revision
